@@ -86,7 +86,7 @@ class RPCServer(object):
     async def __call_worker(self, websocket, rpc_id, method, **params) -> None:
         try:
             self.__sender_ws = websocket
-            rpc_result = await mc.call(websocket.remote_address, method,
+            rpc_result = await mc.call(websocket, method,
                                        **params)
             feedback = self.__pack_rpc(rpc_id, rpc_result)
         except Exception as e:
@@ -129,7 +129,7 @@ class RPCServer(object):
         self.__ws_clients.add(websocket)
 
         if self.__on_connected:
-            result = self.__on_connected(websocket.remote_address)
+            result = self.__on_connected(websocket)
             if asyncio.iscoroutine(result):
                 await result
 
@@ -175,7 +175,7 @@ class RPCServer(object):
         self.__ws_clients.remove(websocket)
 
         if self.__on_disconnected:
-            result = self.__on_disconnected(websocket.remote_address)
+            result = self.__on_disconnected(websocket)
             if asyncio.iscoroutine(result):
                 await result
 
